@@ -19,6 +19,7 @@ class PartialFileHandle:
 	original_data_str: str
 	indent_level: int
 	indent_with: str
+	index_data: dict
 
 
 ################################################################################
@@ -58,9 +59,8 @@ def read(db_name: str) -> dict:
 		Make sure the file exists. If it does notnot a FileNotFoundError is
 		raised.
 	"""
-	if config.use_orjson:
-		return orjson.loads(read_file(db_name, as_bytes=True))
-	return json.loads(read_file(db_name))
+	# Always use orjson to read the file, because it is faster
+	return orjson.loads(read_file(db_name, as_bytes=True))
 
 
 
@@ -69,18 +69,15 @@ def read_index_file(db_name: str):
 	Path(path).parent.mkdir(parents=True, exist_ok=True)
 	if not os.path.exists(path):
 		return {}
-	with open(path, "r") as f:
-		return json.load(f)
+	with open(path, "rb") as f:
+		return orjson.loads(f.read())
 
 
-def write_index_file(db_name: str, key, start_index, end_index, indent_level, indent_with, value_hash):
-	path = f"{config.storage_directory}/.ddb/{db_name}.index"
-	Path(path).parent.mkdir(parents=True, exist_ok=True)
-	indices = read_index_file(db_name)
-	indices[key] = [start_index, end_index, indent_level, indent_with, value_hash]
-	with open(path, "w") as f:
-		json.dump(indices, f)
-
+def write_index_file(index_data: dict, db_name: str, key, start_index, end_index, indent_level, indent_with, value_hash):
+	path = f"{config.storage_directory}/.ddb/{db_name.replace('/', '___')}.index"
+	index_data[key] = [start_index, end_index, indent_level, indent_with, value_hash]
+	with open(path, "wb") as f:
+		f.write(orjson.dumps(index_data))
 
 
 def partial_read(db_name: str, key: str) -> PartialFileHandle:
@@ -94,19 +91,21 @@ def partial_read(db_name: str, key: str) -> PartialFileHandle:
 	"""
 
 	data = read_file(db_name)
-	index = read_index_file(db_name).get(key, None)
+	index_data = read_index_file(db_name)
+	index = index_data.get(key, None)
 	if index is not None:
 		partial_str = data[index[0]:index[1]]
 		if index[4] == hashlib.sha256(partial_str.encode()).hexdigest():
 			return PartialFileHandle(
 				db_name=db_name,
 				key=key,
-				key_value=json.loads(partial_str),
+				key_value=orjson.loads(partial_str),
 				value_start_index=index[0],
 				value_end_index=index[1],
 				indent_level=index[2],
 				indent_with=index[3],
 				original_data_str=data,
+				index_data=index_data,
 			)
 
 	key_str = f"\"{key}\":"
@@ -126,32 +125,33 @@ def partial_read(db_name: str, key: str) -> PartialFileHandle:
 		indentation_str += data[i]
 
 	if "\t" in indentation_str:
-		indent_with = "\t"
 		indent_level = len(indentation_str)
+		indent_with = "\t"
 	elif isinstance(config.indent, int) and config.indent > 0:
-		indent_with = " " * (len(indentation_str) // config.indent)
 		indent_level = len(indentation_str) // config.indent
+		indent_with = " " * config.indent
 	elif isinstance(config.indent, str):
-		indent_with = "  "
 		indent_level = len(indentation_str) // 2
+		indent_with = "  "
 	else:
-		indent_with, indent_level = "", 0
+		indent_level, indent_with  = 0, ""
 
 
 	value_start_index = key_str_index + len(key_str) + space_after_semicolon
 	value_end_index = utils.seek_index_through_value(data, value_start_index)
 
-	write_index_file(db_name, key, value_start_index, value_end_index, indent_level, indent_with, hashlib.sha256(data[value_start_index:value_end_index].encode()).hexdigest())
+	write_index_file(index_data, db_name, key, value_start_index, value_end_index, indent_level, indent_with, hashlib.sha256(data[value_start_index:value_end_index].encode()).hexdigest())
 
 	return PartialFileHandle(
 		db_name=db_name,
 		key=key,
-		key_value=json.loads(data[value_start_index:value_end_index]),
+		key_value=orjson.loads(data[value_start_index:value_end_index]),
 		value_start_index=value_start_index,
 		value_end_index=value_end_index,
 		original_data_str=data,
 		indent_level=indent_level,
 		indent_with=indent_with,
+		index_data=index_data,
 	)
 
 
@@ -192,9 +192,9 @@ def write(db_name: str, db: dict):
 		to the file of the db_path.
 	"""
 	if config.use_orjson:
-		orjson_indent = orjson.OPT_INDENT_2 if config.indent else 0
-		orjson_sort_keys = orjson.OPT_SORT_KEYS if config.sort_keys else 0
-		db_dump = orjson.dumps(db, option=orjson_indent | orjson_sort_keys)
+		option = orjson.OPT_INDENT_2 if config.indent else 0
+		option |= orjson.OPT_SORT_KEYS if config.sort_keys else 0
+		db_dump = orjson.dumps(db, option=option)
 	else:
 		db_dump = json.dumps(db, indent=config.indent, sort_keys=config.sort_keys)
 
@@ -206,9 +206,9 @@ def partial_write(pf: PartialFileHandle):
 		Write a partial file handle to the db.
 	"""
 	if config.use_orjson:
-		orjson_indent = orjson.OPT_INDENT_2 if config.indent else 0
-		orjson_sort_keys = orjson.OPT_SORT_KEYS if config.sort_keys else 0
-		partial_dump = orjson.dumps(pf.key_value, option=orjson_indent | orjson_sort_keys)
+		option = orjson.OPT_INDENT_2 if config.indent else 0
+		option |= orjson.OPT_SORT_KEYS if config.sort_keys else 0
+		partial_dump = orjson.dumps(pf.key_value, option=option)
 		partial_dump = partial_dump.decode()
 	else:
 		partial_dump = json.dumps(pf.key_value, indent=config.indent, sort_keys=config.sort_keys)
@@ -218,5 +218,14 @@ def partial_write(pf: PartialFileHandle):
 
 	dump_start = pf.original_data_str[:pf.value_start_index]
 	dump_end = pf.original_data_str[pf.value_end_index:]
-	write_index_file(pf.db_name, pf.key, len(dump_start), len(dump_start) + len(partial_dump), pf.indent_level, pf.indent_with, hashlib.sha256(partial_dump.encode()).hexdigest())
+	write_index_file(
+		pf.index_data,
+		pf.db_name,
+		pf.key,
+		len(dump_start),
+		len(dump_start) + len(partial_dump),
+		pf.indent_level,
+		pf.indent_with,
+		hashlib.sha256(partial_dump.encode()).hexdigest()
+	)
 	write_dump(pf.db_name, f"{dump_start}{partial_dump}{dump_end}")
