@@ -69,7 +69,7 @@ class DDBSession(Generic[T]):
 				self.write_lock._lock()
 				self.original_data = io_unsafe.read(self.db_name)
 				data = {}
-				for k, v in self.original_data:
+				for k, v in self.original_data.items():
 					if self.where(k, v):
 						data[k] = v
 				self.data_handle = data
@@ -125,7 +125,8 @@ class DDBSession(Generic[T]):
 		elif self.op_type.file_key:
 			io_unsafe.partial_write(self.partial_handle)
 		elif self.op_type.file_where:
-			io_unsafe.write(self.db_name, self.original_data | self.data_handle)
+			self.original_data.update(self.data_handle)
+			io_unsafe.write(self.db_name, self.original_data)
 		elif self.op_type.dir_normal or self.op_type.dir_where:
 			for name in self.db_name:
 				io_unsafe.write(name, self.data_handle[name.split("/")[-1]])
